atomate.vasp.fireworks package — atomate 0.3 documentation

# atomate.vasp.fireworks package

## Submodules

## atomate.vasp.fireworks.core module

class `atomate.vasp.fireworks.core.` `BoltztrapFW`(structure, name=u'boltztrap', db_file=None, parents=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, name=u'boltztrap', db_file=None, parents=None, **kwargs)

    Run Boltztrap

    Args:
      structure: (Structure) - only used for setting name of FW name: (str) name of this FW parents (Firework): Parents of this particular Firework. FW or list of FWS. **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `HSEBSFW`(structure, parents, mode=u'gap', name=None, vasp_cmd=u'vasp', db_file=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, parents, mode=u'gap', name=None, vasp_cmd=u'vasp', db_file=None, **kwargs)

    For getting a more accurate band gap or a full band structure with HSE - requires previous calculation that gives VBM/CBM info or the high-symmetry kpoints.

    Args:

      structure (Structure): Input structure. parents (Firework): Parents of this particular Firework. FW or list of FWS. mode (string): options:

      > “line” to get a full band structure along symmetry lines or “gap” to get the energy at the CBM and VBM

      name (str): Name for the Firework. vasp_cmd (str): Command to run vasp. db_file (str): Path to file specifying db credentials. **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `LepsFW`(structure, name=u'static dielectric', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, phonon=False, mode=None, displacement=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, name=u'static dielectric', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, phonon=False, mode=None, displacement=None, **kwargs)

    Standard static calculation Firework for dielectric constants using DFPT.

    Args:

      structure (Structure): Input structure. name (str): Name for the Firework. vasp_cmd (str): Command to run vasp. copy_vasp_outputs (bool): Whether to copy outputs from previous

      > run. Defaults to True.

      db_file (str): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework.

      > FW or list of FWS.

      phonon (bool): Whether or not to extract normal modes and pass it. This argument along
        with the mode and displacement arguments must be set for the calculation of dielectric constant in the Raman tensor workflow.

      mode (int): normal mode index. displacement (float): displacement along the normal mode in Angstroms. **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `MDFW`(structure, start_temp, end_temp, nsteps, name=u'molecular dynamics run', vasp_input_set=None, vasp_cmd=u'vasp', override_default_vasp_params=None, wall_time=19200, db_file=None, parents=None, copy_vasp_outputs=True, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, start_temp, end_temp, nsteps, name=u'molecular dynamics run', vasp_input_set=None, vasp_cmd=u'vasp', override_default_vasp_params=None, wall_time=19200, db_file=None, parents=None, copy_vasp_outputs=True, **kwargs)

    Standard firework for a single MD run.

    Args:

      structure (Structure): Input structure. start_temp (float): Start temperature of MD run. end_temp (float): End temperature of MD run. nsteps (int): Number of MD steps name (string): Name for the Firework. vasp_input_set (string): string name for the VASP input set (e.g.,

      > “MITMDVaspInputSet”).

      vasp_cmd (string): Command to run vasp. override_default_vasp_params (dict): If this is not None,

      > these params are passed to the default vasp_input_set, i.e., MITMDSet. This allows one to easily override some settings, e.g., user_incar_settings, etc. Particular to MD, one can control time_step and all other settings of the input set.

      wall_time (int): Total wall time in seconds. copy_vasp_outputs (bool): Whether to copy outputs from previous run. Defaults to True. db_file (string): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework. FW or list of FWS. **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `NonSCFFW`(structure, name=u'nscf', mode=u'uniform', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, name=u'nscf', mode=u'uniform', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

    Standard NonSCF Calculation Firework supporting both uniform and line modes.

    Args:

      structure (Structure): Input structure. name (str): Name for the Firework. mode (str): uniform or line mode. vasp_cmd (str): Command to run vasp. copy_vasp_outputs (bool): Whether to copy outputs from previous

      > run. Defaults to True.

      db_file (str): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework.

      > FW or list of FWS.

      **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `OptimizeFW`(structure, name=u'structure optimization', vasp_input_set=None, vasp_cmd=u'vasp', override_default_vasp_params=None, ediffg=None, db_file=None, parents=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, name=u'structure optimization', vasp_input_set=None, vasp_cmd=u'vasp', override_default_vasp_params=None, ediffg=None, db_file=None, parents=None, **kwargs)

    Standard structure optimization Firework.

    Args:

      structure (Structure): Input structure. name (str): Name for the Firework. vasp_input_set (VaspInputSet): input set to use.

      > Defaults to MPRelaxSet() if None.

      override_default_vasp_params (dict): If this is not None,
        these params are passed to the default vasp_input_set, i.e., MPRelaxSet. This allows one to easily override some settings, e.g., user_incar_settings, etc.

      vasp_cmd (str): Command to run vasp. ediffg (float): Shortcut to set ediffg in certain jobs db_file (str): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework.

      > FW or list of FWS.

      **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `SOCFW`(structure, magmom, name=u'spinorbit coupling', saxis=(0, 0, 1), vasp_cmd=u'vasp_ncl', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, magmom, name=u'spinorbit coupling', saxis=(0, 0, 1), vasp_cmd=u'vasp_ncl', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

    Firework for spin orbit coupling calculation.

    Args:

      structure (Structure): Input structure. name (str): Name for the Firework. vasp_cmd (str): Command to run vasp. copy_vasp_outputs (bool): Whether to copy outputs from previous

      > run. Defaults to True.

      db_file (str): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework.

      > FW or list of FWS.

      **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `StaticFW`(structure, name=u'static', vasp_input_set=None, vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, name=u'static', vasp_input_set=None, vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, **kwargs)

    Standard static calculation Firework.

    Args:

      structure (Structure): Input structure. name (str): Name for the Firework. vasp_input_set (VaspInputSet): input set to use (for jobs w/no parents)

      > Defaults to MPStaticSet() if None.

      vasp_cmd (str): Command to run vasp. copy_vasp_outputs (bool): Whether to copy outputs from previous run. Defaults to True. db_file (str): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework. FW or list of FWS. **kwargs: Other kwargs that are passed to Firework.__init__.

class `atomate.vasp.fireworks.core.` `TransmuterFW`(structure, transformations, transformation_params=None, vasp_input_set=None, name=u'structure transmuter', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, override_default_vasp_params=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(structure, transformations, transformation_params=None, vasp_input_set=None, name=u'structure transmuter', vasp_cmd=u'vasp', copy_vasp_outputs=True, db_file=None, parents=None, override_default_vasp_params=None, **kwargs)

    Apply the transformations to the input structure, write the input set corresponding to the transformed structure and run vasp on them.

    Args:

      structure (Structure): Input structure. transformations (list): list of names of transformation classes as defined in

      > the modules in pymatgen.transformations. eg: transformations=[‘DeformStructureTransformation’, ‘SupercellTransformation’]

      transformation_params (list): list of dicts where each dict specify the input parameters to
        instantiate the transformation class in the transformations list.
      vasp_input_set (VaspInputSet): VASP input set, used to write the input set for the
        transmuted structure.

      name (string): Name for the Firework. vasp_cmd (string): Command to run vasp. copy_vasp_outputs (bool): Whether to copy outputs from previous run. Defaults to True. db_file (string): Path to file specifying db credentials. parents (Firework): Parents of this particular Firework. FW or list of FWS. override_default_vasp_params (dict): additional user input settings for vasp_input_set. **kwargs: Other kwargs that are passed to Firework.__init__.

## Module contents